# Introduction
This is a tool for automatically fetching the journal's level information from CCF(2019) and Letpub.

# Installation
```
pip install journal_search
playwright install
```

# Start
```
python -m journal_search
```